@@ -352,6 +352,13 @@ class _Parser(object):
         if operator == '$in':
             expression, array = values
             return self.parse(expression) in self.parse(array)
+        if operator == '$setUnion':
+            result = []
+            for set_value in values:
+                for value in self.parse(set_value):
+                    if value not in result:
+                        result.append(value)
+            return result
         raise NotImplementedError(
             "Although '%s' is a valid set operator for the aggregation "
             'pipeline, it is currently not implemented in Mongomock.' % operator)
@@ -706,7 +713,7 @@ def _handle_project_stage(in_collection, unused_database, options):
                 out_doc[field] = _parse_expression(value, in_doc)
             except KeyError:
                 pass
-    if (method == 'include') == (include_id is not False):
+    if (method == 'include') == (include_id is not False and include_id is not 0):
         filter_list.append('_id')
 
     if not filter_list:
